@@ -711,7 +711,43 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
                 '<xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu',
             ]
         )
-        assert bytes(store) == content
+        # Additional entry for many (decimal) is present
+        assert (
+            bytes(store).decode()
+            == """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <plurals name="teststring">
+        <item quantity="one"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> den</item>
+        <item quantity="few"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dny</item>
+        <item quantity="many"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu</item>
+        <item quantity="other"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu</item>
+    </plurals>
+</resources>
+"""
+        )
+
+    def test_parse_decimal_plurals(self):
+        content = b"""<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <plurals name="teststring">
+        <item quantity="one"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> den</item>
+        <item quantity="few"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dny</item>
+        <item quantity="many"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dni</item>
+        <item quantity="other"><xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu</item>
+    </plurals>
+</resources>
+"""
+        # Resulting parsed plurals are still the same
+        store = self.StoreClass()
+        store.targetlanguage = "cs"
+        store.parse(content)
+        store.units[0].target = multistring(
+            [
+                '<xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> den',
+                '<xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dny',
+                '<xliff:g xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2" id="count">%d</xliff:g> dnu',
+            ]
+        )
 
     def entity_add(self, *, edit: bool):
         content = """<?xml version="1.0" encoding="utf-8"?>
@@ -922,6 +958,27 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         store.parse(content.encode())
         assert store.units[0].target == multistring(["%d visitor", "", "%d visitors"])
 
+    def test_empty_missing_plural_tag(self):
+        content = """<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <plurals name="1" />
+    <plurals name="2">
+      <item quantity="other">%1$d tiles left in pool.</item>
+    </plurals>
+    <plurals name="3">
+      <item quantity="other">%1$d tiles left in pool.</item>
+      <item quantity="one">%1$d tile left in pool.</item>
+    </plurals>
+</resources>
+"""
+        store = self.StoreClass()
+        store.parse(content.encode())
+        assert store.units[0].target == multistring(["", ""])
+        assert store.units[1].target == multistring(["", "%1$d tiles left in pool."])
+        assert store.units[2].target == multistring(
+            ["%1$d tile left in pool.", "%1$d tiles left in pool."]
+        )
+
     def test_removeunit(self):
         content = """<?xml version="1.0" encoding="utf-8"?>
 <resources>
@@ -1139,3 +1196,44 @@ class TestCMPResourceUnit(TestMOKOResourceUnit):
 
 class TestCMPResourceFile(test_monolingual.TestMonolingualStore):
     StoreClass = aresource.CMPResourceFile
+
+    def test_quote_escape(self):
+        store = self.StoreClass()
+
+        # Test parsing
+        store.parse(
+            r"""<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <string name="cloud_changelogScreen_title">Bienvenue dans la version préliminaire de l\'application Efento Cloud</string>
+</resources>
+""".encode()
+        )
+        assert len(store.units) == 1
+        assert (
+            store.units[0].target
+            == r"Bienvenue dans la version préliminaire de l\'application Efento Cloud"
+        )
+
+        # Test updating
+        store.units[
+            0
+        ].target = "Bienvenue dans la version préliminaire de l'application"
+        assert (
+            bytes(store).decode()
+            == r"""<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <string name="cloud_changelogScreen_title">Bienvenue dans la version préliminaire de l'application</string>
+</resources>
+"""
+        )
+        store.units[
+            0
+        ].target = r"Bienvenue dans la version préliminaire de l\'application"
+        assert (
+            bytes(store).decode()
+            == r"""<?xml version="1.0" encoding="utf-8"?>
+<resources>
+    <string name="cloud_changelogScreen_title">Bienvenue dans la version préliminaire de l\\'application</string>
+</resources>
+"""
+        )
